@@ -1,4 +1,4 @@
-/* Copyright (C) 2004, 2005, 2006, 2007, 2008 Bart Hakvoort
+/* Copyright (C) 2004, 2005, 2006, 2007, 2008, 2009 Bart Hakvoort
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -31,6 +31,7 @@
 
 #include <iostream>
 #include <ctime>
+#include <vector>
 
 namespace GParted
 {
@@ -52,20 +53,25 @@ enum FILESYSTEM
 	
 	FS_EXT2		= 4,
 	FS_EXT3		= 5,
-	FS_LINUX_SWAP	= 6,
-	FS_FAT16	= 7,
-	FS_FAT32	= 8,
-	FS_NTFS		= 9,
-	FS_REISERFS	= 10,
-	FS_REISER4	= 11,
-	FS_XFS		= 12,
-	FS_JFS		= 13,
-	FS_HFS		= 14,
-	FS_HFSPLUS	= 15,
-	FS_UFS		= 16,
+	FS_EXT4		= 6,
+	FS_LINUX_SWAP	= 7,
+	FS_FAT16	= 8,
+	FS_FAT32	= 9,
+	FS_NTFS		= 10,
+	FS_REISERFS	= 11,
+	FS_REISER4	= 12,
+	FS_XFS		= 13,
+	FS_JFS		= 14,
+	FS_HFS		= 15,
+	FS_HFSPLUS	= 16,
+	FS_UFS		= 17,
 
-	FS_USED		= 17,
-	FS_UNUSED	= 18
+	FS_USED		= 18,
+	FS_UNUSED	= 19,
+
+	FS_BTRFS	= 20,  /* FIXME: Move this higher up list when full support added */
+	FS_LVM2		= 21,
+	FS_LUKS		= 22
 } ;
 
 enum SIZE_UNIT
@@ -121,6 +127,7 @@ public:
 			      	      Gtk::AlignmentEnum x_align = Gtk::ALIGN_LEFT,
 			      	      Gtk::AlignmentEnum y_align = Gtk::ALIGN_CENTER,
 				      bool wrap = false,
+				      bool selectable = false,
 				      const Glib::ustring & text_color = "black" ) ;
 	static Glib::ustring num_to_str( Sector number, bool use_C_locale = false ) ;
 	static Glib::ustring get_color( FILESYSTEM filesystem ) ;
@@ -144,7 +151,9 @@ public:
 	static Glib::ustring trim( const Glib::ustring & src, const Glib::ustring & c = " \t\r\n" ) ;
 	static Glib::ustring cleanup_cursor( const Glib::ustring & text ) ;
 	static Glib::ustring get_lang() ;
-
+	static void tokenize( const Glib::ustring& str,
+	                      std::vector<Glib::ustring>& tokens,
+	                      const Glib::ustring& delimiters ) ;
 };
 
 
